==> qmmp-0.4.1.tar.bz2: qmmp-0.4.1/src/plugins/Input/cue/translations/cue_plugin_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>DecoderCUEFactory</name>
    <message>
        <location filename="../decodercuefactory.cpp" line="44"/>
        <source>CUE Plugin</source>
        <translation>Wtyczka CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="47"/>
        <source>CUE Files</source>
        <translation>Pliki CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="85"/>
        <source>About CUE Audio Plugin</source>
        <translation>O wtyczce CUE Audio</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="86"/>
        <source>Qmmp CUE Audio Plugin</source>
        <translation>O wtyczce CUE dla Qmmp</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="87"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CUE Plugin Settings</source>
        <translation>Ustawienia wtyczki CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CUE encoding</source>
        <translation>Kodowanie CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Automatic charset detection</source>
        <translation>Automatyczne wykrywanie kodowania</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Language:</source>
        <translation>Język:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="65"/>
        <source>Default encoding:</source>
        <translation>Domyślne kodowanie:</translation>
    </message>
</context>
</TS>

==> qmmp-0.4.5.tar.bz2: qmmp-0.4.5/src/plugins/Input/cue/translations/cue_plugin_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>DecoderCUEFactory</name>
    <message>
        <location filename="../decodercuefactory.cpp" line="44"/>
        <source>CUE Plugin</source>
        <translation>Wtyczka CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="47"/>
        <source>CUE Files</source>
        <translation>Pliki CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="95"/>
        <source>About CUE Audio Plugin</source>
        <translation>O wtyczce CUE Audio</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="96"/>
        <source>Qmmp CUE Audio Plugin</source>
        <translation>O wtyczce CUE dla Qmmp</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="97"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CUE Plugin Settings</source>
        <translation>Ustawienia wtyczki CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CUE encoding</source>
        <translation>Kodowanie CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Automatic charset detection</source>
        <translation>Automatyczne wykrywanie kodowania</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Language:</source>
        <translation>Język:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="65"/>
        <source>Default encoding:</source>
        <translation>Domyślne kodowanie:</translation>
    </message>
</context>
</TS>
